#!/usr/bin/env python3

"""
A QT based GUI for validating Austrian social security numbers.

Copyright (C) 2013 Gerald Senarclens de Grancy <oss@senarclens.eu>

This module is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.
"""

import sys
from PyQt5 import QtWidgets, QtCore
from validate_ssn import is_valid

class SSNValidationWindow(QtWidgets.QWidget):
    def __init__(self, parent=None):
        """
        Set up the main window.
        """
        QtWidgets.QWidget.__init__(self, parent)
        self.setGeometry(300, 300, 350, 80)
        self.setWindowTitle('Austrian SSN Validator')

        validate = QtWidgets.QPushButton("Enter SSN")
        self.result = QtWidgets.QLabel("")

        grid = QtWidgets.QGridLayout()
        grid.setSpacing(10)
        grid.addWidget(validate, 1, 0)
        grid.addWidget(self.result, 1, 1)

        validate.clicked.connect(self.validationDialog)
        self.setLayout(grid)

    def validationDialog(self):
        """
        Show a dialog window and validate the entered SSN.
        """
        text, ok = QtWidgets.QInputDialog.getText(self, 'SSN',
            'Enter a social security number:')
        try:
            ssn = [int(c) for c in text]
            valid = is_valid(ssn)
        except:
            valid = False

        if ok:
            if valid:
                self.result.setText(text + " is VALID")
            else:
                self.result.setText(text + " is INVALID")


if __name__ == "__main__":
    app = QtWidgets.QApplication(sys.argv)
    window = SSNValidationWindow()
    window.show()
    sys.exit(app.exec_())
